@@ -6,7 +6,7 @@
 #define COLAMD_H
 
 #define _GLPSTD_STDIO
-#include "glplib.h"
+#include "env.h"
 
 #define COLAMD_DATE "Nov 1, 2007"
 #define COLAMD_VERSION_CODE(main, sub) ((main) * 1000 + (sub))
