@@ -4,9 +4,9 @@
 *  This code is part of GLPK (GNU Linear Programming Kit).
 *
 *  Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008,
-*  2009, 2010, 2011 Andrew Makhorin, Department for Applied Informatics,
-*  Moscow Aviation Institute, Moscow, Russia. All rights reserved.
-*  E-mail: <mao@gnu.org>.
+*  2009, 2010, 2011, 2013 Andrew Makhorin, Department for Applied
+*  Informatics, Moscow Aviation Institute, Moscow, Russia. All rights
+*  reserved. E-mail: <mao@gnu.org>.
 *
 *  GLPK is free software: you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by
@@ -22,8 +22,9 @@
 *  along with GLPK. If not, see <http://www.gnu.org/licenses/>.
 ***********************************************************************/
 
-#include "glpapi.h"
-#include "minisat/minisat.h"
+#include "env.h"
+#include "minisat.h"
+#include "prob.h"
 
 int glp_minisat1(glp_prob *P)
 {     /* solve CNF-SAT problem with MiniSat solver */
@@ -49,8 +50,9 @@ int glp_minisat1(glp_prob *P)
       }
       /* solve CNF-SAT problem */
       xprintf("Solving CNF-SAT problem...\n");
-      xprintf("Instance has %d variable%s and %d clause%s\n",
-         P->n, P->n == 1 ? "" : "s", P->m, P->m == 1 ? "" : "s");
+      xprintf("Instance has %d variable%s, %d clause%s, and %d literal%"
+         "s\n", P->n, P->n == 1 ? "" : "s", P->m, P->m == 1 ? "" : "s",
+         P->nnz, P->nnz == 1 ? "" : "s");
       /* if CNF-SAT has no clauses, it is satisfiable */
       if (P->m == 0)
       {  P->mip_stat = GLP_OPT;
